fn validate_target(
planned_obj: &DatabaseObject,
target: &ExplainTarget,
) -> Result<String, CliError>Expand description
Validate the target is an MV or index and return the target cluster name.
fn validate_target(
planned_obj: &DatabaseObject,
target: &ExplainTarget,
) -> Result<String, CliError>Validate the target is an MV or index and return the target cluster name.